/*
 * This is part of Geomajas, a GIS framework, http://www.geomajas.org/.
 *
 * Copyright 2008-2012 Geosparc nv, http://www.geosparc.com/, Belgium.
 *
 * The program is available in open source according to the GNU Affero
 * General Public License. All contributions in this program are covered
 * by the Geomajas Contributors License Agreement. For full licensing
 * details, see LICENSE.txt in the project root.
 */
package org.geomajas.plugin.printing.document;

import java.io.OutputStream;
import java.text.DateFormat;
import java.util.Date;

import org.geomajas.plugin.printing.PrintingException;

/**
 * <p>
 * Wrapper for a pdf document generated by iText, the wrapper contains
 * the document in memory as a ByteArrayOutputStream and attributes how
 * the file is downloaded.
 * </p>
 *
 * @author Oliver May
 */
public abstract class AbstractDocument implements Document {

	protected String fileName;

	/**
	 * @return the filename we want to give this document, this is generated
	 *         using the current date/time if no explicit filename is set.
	 */
	public String getFilename() {
		if (fileName != null) {
			return fileName;
		} else {
			return "geomajas_" + DateFormat.getInstance().format(new Date()) + ".pdf";
		}
	}

	public void setFileName(String fileName) {
		this.fileName = fileName;
	}


	public abstract void render(OutputStream os, Format format) throws PrintingException;

}
